==> rc-tooltip-2.2.0.tgz: package/lib/Tooltip.js <==
'use strict';

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = (function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ('value' in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; })();

var _get = function get(_x, _x2, _x3) { var _again = true; _function: while (_again) { var object = _x, property = _x2, receiver = _x3; desc = parent = getter = undefined; _again = false; if (object === null) object = Function.prototype; var desc = Object.getOwnPropertyDescriptor(object, property); if (desc === undefined) { var parent = Object.getPrototypeOf(object); if (parent === null) { return undefined; } else { _x = parent; _x2 = property; _x3 = receiver; _again = true; continue _function; } } else if ('value' in desc) { return desc.value; } else { var getter = desc.get; if (getter === undefined) { return undefined; } return getter.call(receiver); } } };

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError('Cannot call a class as a function'); } }

function _inherits(subClass, superClass) { if (typeof superClass !== 'function' && superClass !== null) { throw new TypeError('Super expression must either be null or a function, not ' + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) subClass.__proto__ = superClass; }

/**
 * @author yiminghe@gmail.com
 */
var React = require('react');
var rcUtil = require('rc-util');
var createChainedFunction = rcUtil.createChainedFunction;
var Popup = require('./Popup');

var Tooltip = (function (_React$Component) {
  function Tooltip(props) {
    var _this = this;

    _classCallCheck(this, Tooltip);

    _get(Object.getPrototypeOf(Tooltip.prototype), 'constructor', this).call(this, props);
    this.state = {
      visible: !!props.defaultVisible
    };
    if ('visible' in props) {
      this.state.visible = !!props.visible;
    }
    ['toggle', 'show', 'hide'].forEach(function (m) {
      _this[m] = _this[m].bind(_this);
    });
  }

  _inherits(Tooltip, _React$Component);

  _createClass(Tooltip, [{
    key: 'componentWillReceiveProps',
    value: function componentWillReceiveProps(nextProps) {
      if ('visible' in nextProps) {
        this.setState({
          visible: !!nextProps.visible
        });
      }
    }
  }, {
    key: 'getTipContainer',
    value: function getTipContainer() {
      if (!this.tipContainer) {
        this.tipContainer = document.createElement('div');
        document.body.appendChild(this.tipContainer);
      }
      return this.tipContainer;
    }
  }, {
    key: 'getPopupElement',
    value: function getPopupElement() {
      if (!this.popupRendered) {
        return null;
      }
      var props = this.props;
      var state = this.state;
      return React.createElement(
        Popup,
        { prefixCls: props.prefixCls,
          visible: state.visible,
          trigger: props.trigger,
          placement: props.placement,
          animation: props.animation,
          wrap: this,
          onClickOutside: this.hide,
          style: props.overlayStyle,
          transitionName: props.transitionName },
        props.overlay
      );
    }
  }, {
    key: 'toggle',
    value: function toggle(e) {
      e.preventDefault();
      if (this.state.visible) {
        this.hide();
      } else {
        this.show();
      }
    }
  }, {
    key: 'setVisible',
    value: function setVisible(visible) {
      if (this.state.visible !== visible) {
        this.setState({
          visible: visible
        });
        this.props.onVisibleChange(visible);
      }
    }
  }, {
    key: 'show',
    value: function show() {
      this.setVisible(true);
    }
  }, {
    key: 'hide',
    value: function hide() {
      this.setVisible(false);
    }
  }, {
    key: 'componentDidMount',
    value: function componentDidMount() {
      this.componentDidUpdate();
    }
  }, {
    key: 'componentDidUpdate',
    value: function componentDidUpdate() {
      if (!this.popupRendered) {
        return;
      }
      if (this.props.renderPopupToBody) {
        React.render(this.getPopupElement(), this.getTipContainer());
      }
    }
  }, {
    key: 'render',
    value: function render() {
      if (this.state.visible) {
        this.popupRendered = true;
      }
      var props = this.props;
      var children = props.children;
      var child = React.Children.only(children);
      var childProps = child.props || {};
      var newChildProps = {};
      var trigger = props.trigger;
      var mouseProps = {};
      if (trigger.indexOf('click') !== -1) {
        newChildProps.onClick = createChainedFunction(this.toggle, childProps.onClick);
      }
      if (trigger.indexOf('hover') !== -1) {
        mouseProps.onMouseEnter = createChainedFunction(this.show, childProps.onMouseEnter);
        mouseProps.onMouseLeave = createChainedFunction(this.hide, childProps.onMouseLeave);
      }
      if (trigger.indexOf('focus') !== -1) {
        newChildProps.onFocus = createChainedFunction(this.show, childProps.onFocus);
        newChildProps.onBlur = createChainedFunction(this.hide, childProps.onBlur);
      }

      var popupElement = props.renderPopupToBody ? null : this.getPopupElement();
      var className = props.prefixCls + '-wrap';

      if (this.state.visible) {
        className += ' ' + props.prefixCls + '-wrap-open';
      }

      return React.createElement(
        'span',
        _extends({ className: className }, mouseProps, { style: props.wrapStyle }),
        rcUtil.Children.mapSelf([React.cloneElement(child, newChildProps), popupElement])
      );
    }
  }]);

  return Tooltip;
})(React.Component);

Tooltip.propTypes = {
  trigger: React.PropTypes.any,
  placement: React.PropTypes.any,
  onVisibleChange: React.PropTypes.func,
  renderPopupToBody: React.PropTypes.bool,
  overlay: React.PropTypes.node.isRequired,
  overlayStyle: React.PropTypes.object,
  wrapStyle: React.PropTypes.object
};

Tooltip.defaultProps = {
  prefixCls: 'rc-tooltip',
  renderPopupToBody: true,
  onVisibleChange: function onVisibleChange() {},
  overlayStyle: {},
  wrapStyle: {},
  placement: 'right',
  trigger: ['hover']
};

module.exports = Tooltip;

==> rc-tooltip-2.2.3.tgz: package/lib/Tooltip.js <==
'use strict';

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = (function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ('value' in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; })();

var _get = function get(_x, _x2, _x3) { var _again = true; _function: while (_again) { var object = _x, property = _x2, receiver = _x3; desc = parent = getter = undefined; _again = false; if (object === null) object = Function.prototype; var desc = Object.getOwnPropertyDescriptor(object, property); if (desc === undefined) { var parent = Object.getPrototypeOf(object); if (parent === null) { return undefined; } else { _x = parent; _x2 = property; _x3 = receiver; _again = true; continue _function; } } else if ('value' in desc) { return desc.value; } else { var getter = desc.get; if (getter === undefined) { return undefined; } return getter.call(receiver); } } };

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError('Cannot call a class as a function'); } }

function _inherits(subClass, superClass) { if (typeof superClass !== 'function' && superClass !== null) { throw new TypeError('Super expression must either be null or a function, not ' + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) subClass.__proto__ = superClass; }

/**
 * @author yiminghe@gmail.com
 */
var React = require('react');
var rcUtil = require('rc-util');
var createChainedFunction = rcUtil.createChainedFunction;
var Popup = require('./Popup');

var Tooltip = (function (_React$Component) {
  function Tooltip(props) {
    var _this = this;

    _classCallCheck(this, Tooltip);

    _get(Object.getPrototypeOf(Tooltip.prototype), 'constructor', this).call(this, props);
    this.state = {
      visible: !!props.defaultVisible
    };
    if ('visible' in props) {
      this.state.visible = !!props.visible;
    }
    ['toggle', 'show', 'hide'].forEach(function (m) {
      _this[m] = _this[m].bind(_this);
    });
  }

  _inherits(Tooltip, _React$Component);

  _createClass(Tooltip, [{
    key: 'getPopupDomNode',
    value: function getPopupDomNode() {
      // for test
      return this.refs.popup ? this.refs.popup.getPopupDomNode() : this.popupInstance.getPopupDomNode();
    }
  }, {
    key: 'componentWillReceiveProps',
    value: function componentWillReceiveProps(nextProps) {
      if ('visible' in nextProps) {
        this.setState({
          visible: !!nextProps.visible
        });
      }
    }
  }, {
    key: 'getTipContainer',
    value: function getTipContainer() {
      if (!this.tipContainer) {
        this.tipContainer = document.createElement('div');
        document.body.appendChild(this.tipContainer);
      }
      return this.tipContainer;
    }
  }, {
    key: 'getPopupElement',
    value: function getPopupElement() {
      if (!this.popupRendered) {
        return null;
      }
      var props = this.props;
      var state = this.state;
      var ref = {};
      if (!props.renderPopupToBody) {
        ref.ref = 'popup';
      }
      return React.createElement(
        Popup,
        _extends({ prefixCls: props.prefixCls
        }, ref, {
          visible: state.visible,
          trigger: props.trigger,
          placement: props.placement,
          animation: props.animation,
          wrap: this,
          onClickOutside: this.hide,
          style: props.overlayStyle,
          transitionName: props.transitionName }),
        props.overlay
      );
    }
  }, {
    key: 'toggle',
    value: function toggle(e) {
      e.preventDefault();
      if (this.state.visible) {
        this.hide();
      } else {
        this.show();
      }
    }
  }, {
    key: 'setVisible',
    value: function setVisible(visible) {
      if (this.state.visible !== visible) {
        this.setState({
          visible: visible
        });
        this.props.onVisibleChange(visible);
      }
    }
  }, {
    key: 'show',
    value: function show() {
      this.setVisible(true);
    }
  }, {
    key: 'hide',
    value: function hide() {
      this.setVisible(false);
    }
  }, {
    key: 'componentDidMount',
    value: function componentDidMount() {
      this.componentDidUpdate();
    }
  }, {
    key: 'componentDidUpdate',
    value: function componentDidUpdate() {
      if (!this.popupRendered) {
        return;
      }
      if (this.props.renderPopupToBody) {
        this.popupInstance = React.render(this.getPopupElement(), this.getTipContainer());
      }
    }
  }, {
    key: 'componentWillUnmount',
    value: function componentWillUnmount() {
      if (this.tipContainer) {
        React.unmountComponentAtNode(this.tipContainer);
        document.body.removeChild(this.tipContainer);
        this.tipContainer = null;
      }
    }
  }, {
    key: 'render',
    value: function render() {
      if (this.state.visible) {
        this.popupRendered = true;
      }
      var props = this.props;
      var children = props.children;
      var child = React.Children.only(children);
      var childProps = child.props || {};
      var newChildProps = {};
      var trigger = props.trigger;
      var mouseProps = {};
      if (trigger.indexOf('click') !== -1) {
        newChildProps.onClick = createChainedFunction(this.toggle, childProps.onClick);
      }
      if (trigger.indexOf('hover') !== -1) {
        mouseProps.onMouseEnter = createChainedFunction(this.show, childProps.onMouseEnter);
        mouseProps.onMouseLeave = createChainedFunction(this.hide, childProps.onMouseLeave);
      }
      if (trigger.indexOf('focus') !== -1) {
        newChildProps.onFocus = createChainedFunction(this.show, childProps.onFocus);
        newChildProps.onBlur = createChainedFunction(this.hide, childProps.onBlur);
      }

      var popupElement = props.renderPopupToBody ? null : this.getPopupElement();
      var className = props.prefixCls + '-wrap';

      if (this.state.visible) {
        className += ' ' + props.prefixCls + '-wrap-open';
      }

      return React.createElement(
        'span',
        _extends({ className: className }, mouseProps, { style: props.wrapStyle }),
        rcUtil.Children.mapSelf([React.cloneElement(child, newChildProps), popupElement])
      );
    }
  }]);

  return Tooltip;
})(React.Component);

Tooltip.propTypes = {
  trigger: React.PropTypes.any,
  placement: React.PropTypes.any,
  onVisibleChange: React.PropTypes.func,
  renderPopupToBody: React.PropTypes.bool,
  overlay: React.PropTypes.node.isRequired,
  overlayStyle: React.PropTypes.object,
  wrapStyle: React.PropTypes.object
};

Tooltip.defaultProps = {
  prefixCls: 'rc-tooltip',
  renderPopupToBody: true,
  onVisibleChange: function onVisibleChange() {},
  overlayStyle: {},
  wrapStyle: {},
  placement: 'right',
  trigger: ['hover']
};

module.exports = Tooltip;
